@@ -932,15 +932,20 @@ class Shvar(RememberInstanceCreationInfo):
         """
         This method split the Filename to varname, Hour, Minute value.
 
-        The input 'Filename' has the form 'varname_Hour:Minute:00'.
+        The input 'Filename' has the form 'varname_Hour-Minute-00'.
         The output is the form '[varname, Hour, Minute]'.
         """
 
         if isinstance(Filename, str) is False:
             raise TypeError("Filename should be a string.")
         
-        varname, time = Filename.split('_')
-        Hour, Minute, Second = time.split(';')
+        # varname, time = Filename.split('_')
+        # Hour, Minute, Second = time.split('-')
+        Second  = Filename[-2:]
+        Minute  = Filename[-5:-3]
+        Hour    = Filename[-8:-6]
+        varname = Filename[:-9]
+        print(varname, Hour, Minute, Second)
         return [varname, Hour, Minute]
     
 
